@@ -1,16 +1,21 @@
+import os
 from pathlib import Path
-from typing import Any, cast, Final, Iterator, Literal, MutableMapping, TypedDict
-import yaml, os
+from typing import Any, Final, Iterator, Literal, MutableMapping, TypedDict, cast
+
+import yaml
+
+from .os import safe_create
 
 ConfigKey = Literal["org"]
 
 
-XDG_CONFIG_HOME = Path(os.getenv("XDG_CONFIG_HOME", str(Path.home() / ".config")))
-SYM_CONFIG_HOME = XDG_CONFIG_HOME / "sym"
-
-
 def sym_config_file(file_name: str) -> Path:
-    return SYM_CONFIG_HOME / file_name
+    try:
+        xdg_config_home = Path(os.environ["XDG_CONFIG_HOME"])
+    except KeyError:
+        xdg_config_home = Path.home() / ".config"
+    sym_config_home = xdg_config_home / "sym"
+    return sym_config_home / file_name
 
 
 class ConfigSchema(TypedDict, total=False):
@@ -27,15 +32,15 @@ class Config(MutableMapping[ConfigKey, Any]):
         self.path = sym_config_file("config.yml")
         self.path.parent.mkdir(parents=True, exist_ok=True)
         try:
-            config = cast(
-                ConfigSchema, yaml.load(self.path.open("r"), Loader=yaml.FullLoader)
-            )
+            with self.path.open() as f:
+                config = cast(ConfigSchema, yaml.safe_load(stream=f))
         except FileNotFoundError:
             config = ConfigSchema()
         self.config = config
 
     def __flush(self) -> None:
-        yaml.dump(self.config, self.path.open("w"))
+        with safe_create(self.path) as f:
+            yaml.safe_dump(self.config, stream=f)
 
     def __getitem__(self, key: ConfigKey) -> Any:
         return self.config[key]
@@ -56,3 +61,6 @@ class Config(MutableMapping[ConfigKey, Any]):
 
     def __repr__(self) -> str:
         return f"{type(self).__name__}({self.path})"
+
+    def get_org(self) -> str:
+        return self.config["org"]
