@@ -24,22 +24,22 @@ class GlobalOptions:
 @setup_sentry(dsn=SENTRY_DSN, release=f"sym-cli@{__version__}")
 @click.group(cls=AutoTagGroup)
 @click.option(
-    "--provider",
-    "provider_name",
+    "--saml-client",
+    "saml_client_name",
     default="auto",
     type=click.Choice(["auto", "aws-okta", "saml2aws"]),
-    help="the provider type to use",
+    help="the SAML client type to use",
 )
 @click.option("--debug", is_flag=True, help="enable verbose debugging")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
-def sym(options: GlobalOptions, provider_name: ProviderName, debug: bool) -> None:
+def sym(options: GlobalOptions, saml_client_name: ProviderName, debug: bool) -> None:
     """Access resources managed by Sym workflows.
 
     Use these tools to work with your resources once you've gotten approval in
     Slack.
     """
 
-    options.provider_type = choose_provider(provider_name)
+    options.provider_type = choose_provider(saml_client_name)
     options.debug = debug
 
 
